==> kdebase-3.0.1.tar.bz2: kdebase-3.0.1/kcontrol/kcontrol/dockcontainer.h <==
/*
  Copyright (c) 2000 Matthias Elter <elter@kde.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

#ifndef __dockcontainer_h__
#define __dockcontainer_h__

#include <qwidget.h>

class ConfigModule;
class QLabel;

class DockContainer : public QWidget
{
  Q_OBJECT

public:
  DockContainer(QWidget *parent=0);
  virtual ~DockContainer();

  void setBaseWidget(QWidget *widget);
  QWidget *baseWidget() { return _basew; }
  
  bool dockModule(ConfigModule *module);

  QSize minimumSizeHint() const;

  QSize sizeHint() const { return minimumSizeHint(); }

public slots:
  void removeModule();

protected slots:
  void quickHelpChanged();

protected:
  void resizeEvent (QResizeEvent *);
  void deleteModule();

signals:
  void newModule(const QString &name, const QString& docPath, const QString &quickhelp);
  void changedModule(ConfigModule *module);

private:
  QWidget      *_basew;
  QLabel       *_busy;
  ConfigModule *_module;

};

#endif

==> kdebase-3.2.3.tar.bz2: kdebase-3.2.3/kcontrol/kcontrol/dockcontainer.h <==
/*
  Copyright (c) 2000 Matthias Elter <elter@kde.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#ifndef __dockcontainer_h__
#define __dockcontainer_h__

#include <qwidgetstack.h>

class ConfigModule;
class ModuleWidget;
class ProxyWidget;
class QLabel;
class QVBox;

class DockContainer : public QWidgetStack
{
  Q_OBJECT

public:
  DockContainer(QWidget *parent=0);
  virtual ~DockContainer();

  void setBaseWidget(QWidget *widget);
  QWidget *baseWidget() { return _basew; }

  bool dockModule(ConfigModule *module);
  ConfigModule *module() { return _module; }

public slots:
  void removeModule();

protected slots:
  void quickHelpChanged();

protected:
  void deleteModule();
  ProxyWidget* loadModule( ConfigModule *module );

signals:
  void newModule(const QString &name, const QString& docPath, const QString &quickhelp);
  void changedModule(ConfigModule *module);

private:
  QWidget      *_basew;
  QLabel       *_busyw;
  ModuleWidget *_modulew;
  ConfigModule *_module;

};

#endif
